# -*- coding: utf8 -*-
# author: Ludwig Reiter

from sqlalchemy import event
import sqlalchemy as sa
from sqlalchemy.orm import relationship
from ringo.model import Base
from euhu.esf import to_esf
from euhu.programs.ec import to_bmas, validate
from efa.model.participant import Participant, \
    generate_determine_reportable_function,listener_adapter
from ringo_bmasreport.reports.durchfuehrungsbericht import (
    indicators, recipe
)


class MatchingParticipant(Base):
    """For including matching participants ids"""
    __tablename__ = 'matching_participants'
    participant_id = sa.Column('participant_id',
                               sa.ForeignKey('participants.id'),
                               primary_key=True)
    matching_participant_id = sa.Column('matching_participant_id',
                                        sa.ForeignKey('participants.id'),
                                        primary_key=True)
    status = sa.Column('status', sa.Integer)
    comment = sa.Column('comment', sa.String)
    participant = relationship(Participant,
                               primaryjoin=participant_id == Participant.id,
                               backref='matching_participants')
    matching_participant = relationship(
        Participant,
        primaryjoin=matching_participant_id == Participant.id)

    def __init__(self, participant_id, matching_participant_id):
        self.participant_id = participant_id
        self.matching_participant_id = matching_participant_id
        self.status = 0


program = "ec"
indicators['RI'].append(('C1.2',u'Teilnehmer/-innen, die erfolgreich eine Qualifizierung zur/m Elternbegleiter/-in abgeschlossen haben (C1.2)'))

def derive_indicators(values):
    return to_esf(to_bmas(values)).esf


td_update_listener = listener_adapter(generate_determine_reportable_function(
        derive_indicators,
        recipe,
        validate,
        program))


event.listen(Participant, 'after_update', td_update_listener)
